@@ -1,13 +1,16 @@
-package File::Marker;
-
-$VERSION = '0.13';
-@ISA = qw( IO::File );
-
+use 5.006;
 use strict;
 use warnings;
+
+package File::Marker;
+# ABSTRACT: Set and jump between named position markers on a filehandle
+our $VERSION = '0.14'; # VERSION
+
+our @ISA = qw( IO::File );
+
 use Carp;
 use IO::File;
-use Scalar::Util qw( refaddr weaken );
+use Scalar::Util 1.09 qw( refaddr weaken );
 
 #--------------------------------------------------------------------------#
 # Inside-out data storage
@@ -25,10 +28,10 @@ my %REGISTRY = ();
 
 sub new {
     my $class = shift;
-    my $self = IO::File->new();
+    my $self  = IO::File->new();
     bless $self, $class;
     weaken( $REGISTRY{ refaddr $self } = $self );
-    $self->open( @_ ) if @_;
+    $self->open(@_) if @_;
     return $self;
 }
 
@@ -39,8 +42,8 @@ sub new {
 sub open {
     my $self = shift;
     $MARKS{ refaddr $self } = {};
-    $self->SUPER::open( @_ );
-    $MARKS{ refaddr $self }{ 'LAST' } = $self->getpos;
+    $self->SUPER::open(@_);
+    $MARKS{ refaddr $self }{'LAST'} = $self->getpos;
     return 1;
 }
 
@@ -49,21 +52,21 @@ sub open {
 #--------------------------------------------------------------------------#
 
 sub set_marker {
-    my ($self, $mark) = @_;
-    
+    my ( $self, $mark ) = @_;
+
     croak "Can't set marker on closed filehandle"
-        if ! $self->opened;
+      if !$self->opened;
+
+    croak "Can't set special marker 'LAST'"
+      if $mark eq 'LAST';
 
-    croak "Can't set special marker 'LAST'" 
-        if $mark eq 'LAST';
-        
     my $position = $self->getpos;
 
     croak "Couldn't set marker '$mark': couldn't locate position in file"
-        if ! defined $position;
-    
-    $MARKS{ refaddr $self }{ $mark } = $self->getpos;
-    
+      if !defined $position;
+
+    $MARKS{ refaddr $self }{$mark} = $self->getpos;
+
     return 1;
 }
 
@@ -72,22 +75,22 @@ sub set_marker {
 #--------------------------------------------------------------------------#
 
 sub goto_marker {
-    my ($self, $mark) = @_;
-    
+    my ( $self, $mark ) = @_;
+
     croak "Can't goto marker on closed filehandle"
-        if ! $self->opened;
+      if !$self->opened;
 
     croak "Unknown file marker '$mark'"
-        if ! exists $MARKS{refaddr $self}{$mark};
-    
+      if !exists $MARKS{ refaddr $self}{$mark};
+
     my $old_position = $self->getpos; # save for LAST
-    
-    my $rc = $self->setpos( $MARKS{ refaddr $self }{ $mark } );
-    
+
+    my $rc = $self->setpos( $MARKS{ refaddr $self }{$mark} );
+
     croak "Couldn't goto marker '$mark': could not seek to location in file"
-        if ! defined $rc;
-    
-    $MARKS{ refaddr $self }{ 'LAST' } = $old_position;
+      if !defined $rc;
+
+    $MARKS{ refaddr $self }{'LAST'} = $old_position;
 
     return 1;
 }
@@ -108,12 +111,12 @@ sub markers {
 sub save_markers {
     my ( $self, $filename ) = @_;
     my $outfile = IO::File->new( $filename, "w" )
-        or croak "Couldn't open $filename for writing";
+      or croak "Couldn't open $filename for writing";
     my $markers = $MARKS{ refaddr $self };
     for my $mark ( keys %$markers ) {
         next if $mark eq 'LAST';
         print $outfile "$mark\n";
-        print $outfile unpack("H*",$markers->{$mark}), "\n";
+        print $outfile unpack( "H*", $markers->{$mark} ), "\n";
     }
     close $outfile;
 }
@@ -125,14 +128,14 @@ sub save_markers {
 sub load_markers {
     my ( $self, $filename ) = @_;
     my $infile = IO::File->new( $filename, "r" )
-        or croak "Couldn't open $filename for reading";
+      or croak "Couldn't open $filename for reading";
     my $markers = $MARKS{ refaddr $self };
     my $mark;
-    while ( defined( $mark = <$infile>) ) {
+    while ( defined( $mark = <$infile> ) ) {
         chomp $mark;
         my $position = <$infile>;
         chomp $position;
-        $position = pack("H*",$position);
+        $position = pack( "H*", $position );
         $markers->{$mark} = $position;
     }
     close $infile;
@@ -155,21 +158,21 @@ sub DESTROY {
 #--------------------------------------------------------------------------#
 
 sub CLONE {
-    for my $old_id ( keys %REGISTRY ) {  
-       
+    for my $old_id ( keys %REGISTRY ) {
+
         # look under old_id to find the new, cloned reference
-        my $object = $REGISTRY{ $old_id };
+        my $object = $REGISTRY{$old_id};
         my $new_id = refaddr $object;
 
         # relocate data
-        $MARKS{ $new_id } = $MARKS{ $old_id };
-        delete $MARKS{ $old_id };
+        $MARKS{$new_id} = $MARKS{$old_id};
+        delete $MARKS{$old_id};
 
         # update the weak reference to the new, cloned object
-        weaken ( $REGISTRY{ $new_id } = $object );
-        delete $REGISTRY{ $old_id };
+        weaken( $REGISTRY{$new_id} = $object );
+        delete $REGISTRY{$old_id};
     }
-   
+
     return;
 }
 
@@ -181,16 +184,21 @@ sub _object_count {
     return scalar keys %REGISTRY;
 }
 
-1; #this line is important and will help the module return a true value
+1;
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 File::Marker - Set and jump between named position markers on a filehandle
 
 =head1 VERSION
 
-This documentation refers to version 0.13.
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -221,7 +229,7 @@ not been tested in production code.
 =head1 USAGE
 
 =head2 new
- 
+
  my $fh = new();
  my $fh = new( @args );
 
@@ -257,7 +265,7 @@ seek fails.
 
 The reserved marker name 'LAST' corresponds to the location in the file prior
 to the most recent call to goto_marker on the object. For example:
- 
+
  # starts at location X in the file
  $fh->goto_marker( 'one' );  # seek to location Y marked by 'one'
  $fh->goto_marker( 'LAST' ); # seek back to X
@@ -290,56 +298,35 @@ Loads markers from a previously-saved external file.  Will overwrite any
 As with all inside-out objects, File::Marker is only thread-safe (including
 Win32 pseudo-forks) for Perl 5.8 or better, which supports the CLONE subroutine.
 
-=head1 BUGS
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
-Please report bugs or feature requests using the CPAN Request Tracker.
-Bugs can be sent by email to C<<< bug-File-Marker@rt.cpan.org >>> or
-submitted using the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=File-Marker>
+=head1 SUPPORT
 
-When submitting a bug or request, please include a test-file or a patch to an
-existing test-file that illustrates the bug or desired feature.
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests through the issue tracker
+at L<https://github.com/dagolden/File-Marker/issues>.
+You will be notified automatically of any progress on your issue.
+
+=head2 Source Code
+
+This is open source software.  The code repository is available for
+public review and contribution under the terms of the license.
+
+L<https://github.com/dagolden/File-Marker>
+
+  git clone https://github.com/dagolden/File-Marker.git
 
 =head1 AUTHOR
 
-David A. Golden (DAGOLDEN)
-
-dagolden@cpan.org
-
-http://dagolden.com/
+David Golden <dagolden@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005, 2006 by David A. Golden
+This software is Copyright (c) 2013 by David Golden.
 
-This program is free software; you can redistribute it andE<sol>or modify it under
-the same terms as Perl itself.
+This is free software, licensed under:
 
-The full text of the license can be found in the LICENSE file included with
-this module.
-
-=head1 DISCLAIMER OF WARRANTY
-
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS ANDE<sol>OR OTHER PARTIES
-PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
-EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
-ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
-YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
-NECESSARY SERVICING, REPAIR, OR CORRECTION.
-
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY ANDE<sol>OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
-LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
-OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
-THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
+  The Apache License, Version 2.0, January 2004
 
 =cut
-
